pub struct FileSpan {
pub file: FileId,
pub span: Span,
}Expand description
A Span together with the file it belongs to.
Combining the file into the type means there is no such thing as an “orphan”
span whose file has to be guessed from context. Operations that combine two
spans (FileSpan::union) require them to share a file, enforced at runtime.
Fields
file: FileIdspan: SpanImplementations